@@ -13,7 +13,7 @@ from pyutils_spirit.spirit_container.spirit_application_container import SpiritA
 
 
 class ContainerAnnotation:
-    spirit_application_container: SpiritApplicationContainer = SpiritApplicationContainer()
+    SPIRIT_APPLICATION_CONTAINER: SpiritApplicationContainer = SpiritApplicationContainer()
 
     @classmethod
     def resource(cls, names: list[str] | str) -> callable:
@@ -27,13 +27,13 @@ class ContainerAnnotation:
         def decorator_func(func):
             def wrapper(*args, **kwargs):
                 if isinstance(names, str):
-                    resources = cls.spirit_application_container.get_resource(signature=names)
+                    resources = cls.SPIRIT_APPLICATION_CONTAINER.get_resource(signature=names)
                     if resources is None:
                         raise ValueError(f"the signature {names} does not exist")
                 else:
                     resources = kwargs["resources"]
                     for name in names:
-                        instance = cls.spirit_application_container.get_resource(signature=name)
+                        instance = cls.SPIRIT_APPLICATION_CONTAINER.get_resource(signature=name)
                         if instance is None:
                             raise ValueError(f"the signature {name} does not exist")
                         resources[name] = instance
@@ -113,11 +113,11 @@ class Component:
         component_cls.__decorator__ = "Component"
 
         def wrapper_component(__cls: type[object]) -> object:
-            __component: object = (ContainerAnnotation.spirit_application_container
+            __component: object = (ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER
                                    .get_resource(signature=self.__signature))
             if __component is None:
                 __component = object.__new__(__cls)
-                ContainerAnnotation.spirit_application_container.set_resource(signature=self.__signature,
+                ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER.set_resource(signature=self.__signature,
                                                                               resource=__component)
             return __component
 
@@ -137,11 +137,11 @@ class Mapper:
         mapper_cls.__decorator__ = "Mapper"
 
         def wrapper_mapper(__cls: type[object]) -> object:
-            __mapper: object = (ContainerAnnotation.spirit_application_container
+            __mapper: object = (ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER
                                 .get_resource(signature=self.__signature))
             if __mapper is None:
                 __mapper = object.__new__(__cls)
-                ContainerAnnotation.spirit_application_container.set_resource(signature=self.__signature,
+                ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER.set_resource(signature=self.__signature,
                                                                               resource=__mapper)
             return __mapper
 
@@ -161,11 +161,11 @@ class Service:
         service_cls.__decorator__ = "Service"
 
         def wrapper_service(__cls: type[object]) -> object:
-            __service: object = (ContainerAnnotation.spirit_application_container
+            __service: object = (ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER
                                  .get_resource(signature=self.__signature))
             if __service is None:
                 __service = object.__new__(__cls)
-                ContainerAnnotation.spirit_application_container.set_resource(signature=self.__signature,
+                ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER.set_resource(signature=self.__signature,
                                                                               resource=__service)
             return __service
 
@@ -186,11 +186,11 @@ class Controller:
         controller_cls.__decorator_path__ = self.__path
 
         def wrapper_controller(__cls: type[object]) -> object:
-            __controller: object = (ContainerAnnotation.spirit_application_container
+            __controller: object = (ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER
                                     .get_resource(signature=self.__path))
             if __controller is None:
                 __controller = object.__new__(__cls)
-                ContainerAnnotation.spirit_application_container.set_resource(signature=self.__path,
+                ContainerAnnotation.SPIRIT_APPLICATION_CONTAINER.set_resource(signature=self.__path,
                                                                               resource=__controller)
             return __controller
 
