@@ -25,17 +25,15 @@ from pyutils_spirit.util.json_util import deep_dumps
 
 from logging import info, INFO, basicConfig, exception
 
-from http.server import BaseHTTPRequestHandler, HTTPServer
-
 from pyutils_spirit.style.resources import draw_spirit_banner
 
 from pyutils_spirit.util.assemble import Assemble, HashAssemble
 
 from pyutils_spirit.spirit_container.request_result import Result
 
-from pyutils_spirit.spirit_container.multipart_file import MultipartFile
+from http.server import BaseHTTPRequestHandler, ThreadingHTTPServer
 
-from pyutils_spirit.concurrent_thread.thread_executor import ThreadExecutor
+from pyutils_spirit.spirit_container.multipart_file import MultipartFile
 
 from pyutils_spirit.exception.exception import BusinessException, SpiritContainerServiceException
 
@@ -48,52 +46,51 @@ SIGNATURE_SET: set[str] = {"Component", "Mapper", "Service", "Controller",
 
 
 class SpiritApplication:
-    __spirit_application: object = None
+    __SPIRIT_APPLICATION: object = None
 
-    __request_body_key__: str = None
+    REQUEST_BODY_KEY: str = None
 
-    __unified_response_type__: bool = None
+    UNIFIED_RESPONSE_TYPE: bool = None
 
-    __container: SpiritApplicationContainer = None
+    __CONTAINER: SpiritApplicationContainer = None
 
-    __lock: Lock = Lock()
+    __LOCK: Lock = Lock()
 
-    __controller_paths_set: set[str] = None
+    __CONTROLLER_PATH_SET: set[str] = None
 
-    __exception_advice_methods__: Assemble[type, MethodType] = None
+    EXCEPTION_ADVICE_ASSEMBLE: Assemble[type, MethodType] = None
 
-    __interceptor_paths_set: set[str] = None
+    __INTERCEPTOR_PATH_SET: set[str] = None
 
-    __interceptor_function_before__: Callable[[BaseHTTPRequestHandler], tuple[int, bool]] = None
+    INTERCEPTOR_BEFORE: Callable[[BaseHTTPRequestHandler], tuple[int, bool]] = None
 
-    __interceptor_function_after__: Callable[[BaseHTTPRequestHandler], None] = None
+    INTERCEPTOR_AFTER: Callable[[BaseHTTPRequestHandler], None] = None
 
     def __init__(self, host: str, port: int,
                  unified_response_type: bool = True,
                  request_body_key: str = "body") -> None:
-        SpiritApplication.__unified_response_type__ = unified_response_type
-        SpiritApplication.__request_body_key__ = request_body_key
+        SpiritApplication.UNIFIED_RESPONSE_TYPE = unified_response_type
+        SpiritApplication.REQUEST_BODY_KEY = request_body_key
         self.__host: str = host
         self.__port: int = port
-        self.__executor = ThreadExecutor()
-        self.__auto_wired_set__ = set()
+        self.__auto_wired_set = set()
 
     def __new__(cls, host: str, port: int,
                 unified_response_type: bool = True,
                 request_body_key: str = "body") -> object:
-        cls.__lock.acquire()
+        cls.__LOCK.acquire()
         try:
-            if cls.__spirit_application is None:
-                cls.__container = SpiritApplicationContainer()
-                cls.__controller_paths_set = set()
-                cls.__exception_advice_methods__ = HashAssemble()
-                cls.__interceptor_paths_set = set()
-                cls.__spirit_application = object.__new__(cls)
+            if cls.__SPIRIT_APPLICATION is None:
+                cls.__CONTAINER = SpiritApplicationContainer()
+                cls.__CONTROLLER_PATH_SET = set()
+                cls.EXCEPTION_ADVICE_ASSEMBLE = HashAssemble()
+                cls.__INTERCEPTOR_PATH_SET = set()
+                cls.__SPIRIT_APPLICATION = object.__new__(cls)
             else:
                 raise SpiritContainerServiceException
-            return cls.__spirit_application
+            return cls.__SPIRIT_APPLICATION
         finally:
-            cls.__lock.release()
+            cls.__LOCK.release()
 
     def __call__(self, cls) -> type:
         module = inspect.getmodule(cls)
@@ -134,29 +131,29 @@ class SpiritApplication:
                     decorator = getattr(obj, "__decorator__", None)
                     if decorator in SIGNATURE_SET:
                         instance = obj()
-                        self.__auto_wired_set__.add(instance)
+                        self.__auto_wired_set.add(instance)
                         if decorator == "Controller":
                             path = getattr(obj, "__decorator_path__")
-                            SpiritApplication.__controller_paths_set.add(path)
+                            SpiritApplication.__CONTROLLER_PATH_SET.add(path)
                         elif decorator == "ExceptionAdvice":
                             for method_name, method in inspect.getmembers(instance):
                                 if isinstance(method, MethodType):
                                     decorator = getattr(method, "__decorator__", None)
                                     if decorator == "ThrowsException":
                                         params = getattr(method, "__decorator_params__")
-                                        SpiritApplication.__exception_advice_methods__.put(params, method)
+                                        SpiritApplication.EXCEPTION_ADVICE_ASSEMBLE.put(params, method)
                         elif decorator == "RequestInterceptor":
-                            SpiritApplication.__interceptor_paths_set = getattr(obj, "__decorator_params__")
+                            SpiritApplication.__INTERCEPTOR_PATH_SET = getattr(obj, "__decorator_params__")
                             for method_name, method in inspect.getmembers(instance):
                                 if isinstance(method, MethodType):
                                     decorator = getattr(method, "__decorator__", None)
                                     if decorator == "InterceptorBefore":
-                                        SpiritApplication.__interceptor_function_before__ = method
+                                        SpiritApplication.INTERCEPTOR_BEFORE = method
                                     elif decorator == "InterceptorAfter":
-                                        SpiritApplication.__interceptor_function_after__ = method
+                                        SpiritApplication.INTERCEPTOR_AFTER = method
 
     def __auto_injected(self) -> None:
-        for instance in self.__auto_wired_set__:
+        for instance in self.__auto_wired_set:
             for method_name, method in inspect.getmembers(instance):
                 if isinstance(method, MethodType):
                     decorator = getattr(method, "__decorator__", None)
@@ -168,16 +165,16 @@ class SpiritApplication:
 
     def __start_service(self, host: str, port: int):
         server_address: tuple[str, int] = (host, port)
-        service = HTTPServer(server_address, self.RequestHandler)
+        service = ThreadingHTTPServer(server_address, self.RequestHandler)
         info("Spirit Container Service Startup successfully")
         info(f"Listening on Server: {host}:{port}")
-        self.__executor.execute(service.serve_forever)
+        service.serve_forever()
 
     @classmethod
-    def __do_interceptor_function__(cls, request_path: str) -> bool:
-        if len(cls.__interceptor_paths_set) == 0:
+    def do_interceptor_function(cls, request_path: str) -> bool:
+        if len(cls.__INTERCEPTOR_PATH_SET) == 0:
             return False
-        for path in cls.__interceptor_paths_set:
+        for path in cls.__INTERCEPTOR_PATH_SET:
             path_list = request_path.split(path, maxsplit=1)
             if len(path_list) == 1:
                 return False
@@ -186,10 +183,10 @@ class SpiritApplication:
         return False
 
     @classmethod
-    def __get_func_kwargs__(cls, path: str, method_type: str) -> [object, callable, dict]:
-        cls.__lock.acquire()
+    def get_func_kwargs(cls, path: str, method_type: str) -> [object, callable, dict]:
+        cls.__LOCK.acquire()
         try:
-            for controller_path in cls.__controller_paths_set:
+            for controller_path in cls.__CONTROLLER_PATH_SET:
                 path_list = path.split(controller_path, maxsplit=1)
                 if len(path_list) == 1:
                     continue
@@ -197,7 +194,7 @@ class SpiritApplication:
                     continue
                 controller_func_path = path_list[1]
                 if len(path_list) == 2 and controller_func_path[0] == "/":
-                    controller = cls.__container.get_resource(signature=controller_path)
+                    controller = cls.__CONTAINER.get_resource(signature=controller_path)
                     for method_name, method in inspect.getmembers(controller):
                         decorator = getattr(method, "__decorator__", None)
                         if decorator is method_type:
@@ -218,49 +215,49 @@ class SpiritApplication:
                                             kwargs[key] = value
                                     return method, kwargs
         finally:
-            cls.__lock.release()
+            cls.__LOCK.release()
         raise ValueError(f"please check the path {path} of {method_type} Method")
 
     class RequestHandler(BaseHTTPRequestHandler):
 
-        __data__ = None
+        __data = None
 
-        __response__ = None
+        __response = None
 
-        __is_interceptor__: bool = False
+        __is_interceptor: bool = False
 
-        __is_pass__: bool = False
+        __is_pass: bool = False
 
-        __response_code__: int = 200
+        __response_code: int = 200
 
         def __init__(self, *args, **kwargs):
             super().__init__(*args, **kwargs)
 
-        def __request_exception_advice__(self, e: Exception):
+        def __request_exception_advice(self, e: Exception):
             exception(e)
-            self.__response_code__ = 500
-            self.__response__ = str(e)
-            method = SpiritApplication.__exception_advice_methods__.get(key=type(e))
+            self.__response_code = 500
+            self.__response = str(e)
+            method = SpiritApplication.EXCEPTION_ADVICE_ASSEMBLE.get(key=type(e))
             if method is not None:
-                self.__response__ = method(e)
-            elif SpiritApplication.__unified_response_type__ is True:
+                self.__response = method(e)
+            elif SpiritApplication.UNIFIED_RESPONSE_TYPE is True:
                 if isinstance(e, BusinessException):
-                    self.__response__ = Result.WARN(self.__response__)
+                    self.__response = Result.WARN(self.__response)
                 else:
-                    self.__response__ = Result.ERROR(self.__response__)
+                    self.__response = Result.ERROR(self.__response)
 
-        def __is_interceptor_func__(self):
-            self.__is_interceptor__ = SpiritApplication.__do_interceptor_function__(self.path)
-            if self.__is_interceptor__:
-                if SpiritApplication.__interceptor_function_before__ is not None:
-                    self.__response_code__, self.__is_pass__ = SpiritApplication.__interceptor_function_before__(self)
-                    if self.__is_pass__ is False:
-                        self.__response__ = Result.WARN(f"the request '{self.path}' is be intercepted")
+        def __is_interceptor_func(self):
+            self.__is_interceptor = SpiritApplication.do_interceptor_function(self.path)
+            if self.__is_interceptor:
+                if SpiritApplication.INTERCEPTOR_BEFORE is not None:
+                    self.__response_code, self.__is_pass = SpiritApplication.INTERCEPTOR_BEFORE(self)
+                    if self.__is_pass is False:
+                        self.__response = Result.WARN(f"the request '{self.path}' is be intercepted")
                         return True
             return False
 
-        def __request_end_func__(self):
-            self.send_response(self.__response_code__)
+        def __request_end_func(self):
+            self.send_response(self.__response_code)
             intercepted = self.headers["X-Intercepted"]
             if intercepted == "True":
                 self.send_header(keyword="X-Intercepted", value="True")
@@ -269,35 +266,35 @@ class SpiritApplication:
             self.send_header(keyword='Access-Control-Allow-Origin', value='*')
             self.send_header(keyword='Content-type', value='application/json')
             self.end_headers()
-            self.wfile.write(deep_dumps(data=self.__response__).encode('utf-8'))
-            if self.__is_interceptor__ and self.__is_pass__:
-                if SpiritApplication.__interceptor_function_after__ is not None:
-                    SpiritApplication.__interceptor_function_after__(self)
+            self.wfile.write(deep_dumps(self.__response).encode('utf-8'))
+            if self.__is_interceptor and self.__is_pass:
+                if SpiritApplication.INTERCEPTOR_AFTER is not None:
+                    SpiritApplication.INTERCEPTOR_AFTER(self)
 
         def do_OPTIONS(self):
             self.send_response(200)
             self.send_header('Access-Control-Allow-Origin', '*')
-            self.send_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE')
-            self.send_header('Access-Control-Allow-Headers', 'Content-Type')
+            self.send_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS')
+            self.send_header('Access-Control-Allow-Headers', '*')
             self.end_headers()
 
         def do_GET(self):
             try:
-                if self.__is_interceptor_func__():
+                if self.__is_interceptor_func():
                     return None
-                func, kwargs = SpiritApplication.__get_func_kwargs__(self.path, "GET")
+                func, kwargs = SpiritApplication.get_func_kwargs(self.path, "GET")
                 if kwargs is not None:
-                    self.__response__ = func(**kwargs)
+                    self.__response = func(**kwargs)
                 else:
-                    self.__response__ = func()
-                if SpiritApplication.__unified_response_type__ is True:
-                    self.__response__ = Result.SUCCESS(self.__response__)
+                    self.__response = func()
+                if SpiritApplication.UNIFIED_RESPONSE_TYPE is True:
+                    self.__response = Result.SUCCESS(self.__response)
             except Exception as e:
-                self.__request_exception_advice__(e)
+                self.__request_exception_advice(e)
             finally:
-                self.__request_end_func__()
+                self.__request_end_func()
 
-        def __get_post_file__(self, post_body_length) -> (dict, bool):
+        def __get_post_file(self, post_body_length) -> (dict, bool):
             if self.headers['Content-Type'].startswith('multipart/form-data'):
                 # 解析请求体
                 field_storage = FieldStorage(fp=self.rfile,
@@ -324,64 +321,63 @@ class SpiritApplication:
             else:
                 data = self.rfile.read(post_body_length)
                 return {
-                    SpiritApplication.__request_body_key__: json.loads(data)
+                    SpiritApplication.REQUEST_BODY_KEY: json.loads(data)
                 }
 
         def do_POST(self):
-            print("到这了 POST", self)
             post_body_length = int(self.headers['Content-Length'])
             try:
-                if self.__is_interceptor_func__():
+                if self.__is_interceptor_func():
                     return None
-                func, kwargs = SpiritApplication.__get_func_kwargs__(self.path, "POST")
+                func, kwargs = SpiritApplication.get_func_kwargs(self.path, "POST")
                 if post_body_length > 0:
-                    self.__data__ = self.__get_post_file__(post_body_length)
+                    self.__data = self.__get_post_file(post_body_length)
                 else:
-                    self.__response_code__ = 400
+                    self.__response_code = 400
                     raise ValueError("Post Method: Request Body must be not empty.")
                 if kwargs is not None:
-                    self.__response__ = func(**kwargs, **self.__data__)
+                    self.__response = func(**kwargs, **self.__data)
                 else:
-                    self.__response__ = func(**self.__data__)
-                if SpiritApplication.__unified_response_type__ is True:
-                    self.__response__ = Result.SUCCESS(self.__response__)
+                    self.__response = func(**self.__data)
+                if SpiritApplication.UNIFIED_RESPONSE_TYPE is True:
+                    self.__response = Result.SUCCESS(self.__response)
             except Exception as e:
-                self.__request_exception_advice__(e)
+                self.__request_exception_advice(e)
             finally:
-                self.__request_end_func__()
+                self.__request_end_func()
 
         def __set_request_arguments(self, kwargs, func):
             if kwargs is not None:
-                if self.__data__ is None:
-                    self.__response__ = func(**kwargs)
+                if self.__data is None:
+                    self.__response = func(**kwargs)
                 else:
-                    self.__response__ = func(**kwargs, **self.__data__)
+                    self.__response = func(**kwargs, **self.__data)
             else:
-                if self.__data__ is None:
-                    self.__response__ = func()
+                if self.__data is None:
+                    self.__response = func()
                 else:
-                    self.__response__ = func(**self.__data__)
+                    self.__response = func(**self.__data)
 
         def do_PUT(self):
             put_body_length = int(self.headers['Content-Length'])
             if put_body_length > 0:
                 data = self.rfile.read(put_body_length)
-                self.__data__ = {
-                    SpiritApplication.__request_body_key__: json.loads(data)
+                self.__data = {
+                    SpiritApplication.REQUEST_BODY_KEY: json.loads(data)
                 }
             else:
-                self.__data__ = None
+                self.__data = None
             try:
-                if self.__is_interceptor_func__():
+                if self.__is_interceptor_func():
                     return None
-                func, kwargs = SpiritApplication.__get_func_kwargs__(self.path, "PUT")
+                func, kwargs = SpiritApplication.get_func_kwargs(self.path, "PUT")
                 self.__set_request_arguments(kwargs=kwargs, func=func)
-                if SpiritApplication.__unified_response_type__ is True:
-                    self.__response__ = Result.SUCCESS(self.__response__)
+                if SpiritApplication.UNIFIED_RESPONSE_TYPE is True:
+                    self.__response = Result.SUCCESS(self.__response)
             except Exception as e:
-                self.__request_exception_advice__(e)
+                self.__request_exception_advice(e)
             finally:
-                self.__request_end_func__()
+                self.__request_end_func()
 
         def do_DELETE(self):
             content = self.headers['Content-Length']
@@ -389,21 +385,21 @@ class SpiritApplication:
                 delete_body_length = int(content)
                 if delete_body_length > 0:
                     data = self.rfile.read(delete_body_length)
-                    self.__data__ = {
-                        SpiritApplication.__request_body_key__: json.loads(data)
+                    self.__data = {
+                        SpiritApplication.REQUEST_BODY_KEY: json.loads(data)
                     }
                 else:
-                    self.__data__ = None
+                    self.__data = None
             else:
-                self.__data__ = None
+                self.__data = None
             try:
-                if self.__is_interceptor_func__():
+                if self.__is_interceptor_func():
                     return None
-                func, kwargs = SpiritApplication.__get_func_kwargs__(self.path, "DELETE")
+                func, kwargs = SpiritApplication.get_func_kwargs(self.path, "DELETE")
                 self.__set_request_arguments(kwargs=kwargs, func=func)
-                if SpiritApplication.__unified_response_type__ is True:
-                    self.__response__ = Result.SUCCESS(self.__response__)
+                if SpiritApplication.UNIFIED_RESPONSE_TYPE is True:
+                    self.__response = Result.SUCCESS(self.__response)
             except Exception as e:
-                self.__request_exception_advice__(e)
+                self.__request_exception_advice(e)
             finally:
-                self.__request_end_func__()
+                self.__request_end_func()
