@@ -27,63 +27,46 @@ basicConfig(level=INFO)
 
 
 class WebSocket(ABC):
-    __socket_server: socket.socket = None
+    __SOCKET_SERVER: socket.socket = None
 
-    __listener_count = None
+    __LISTENER_COUNT = None
 
-    __buffer_size: int = None
+    __BUFFER_SIZE: int = None
 
-    websocket_end_points: set[type] = None
+    WEBSOCKET_END_POINTS: set[type] = None
 
-    __executor: ThreadExecutor = None
+    __EXECUTOR: ThreadExecutor = None
 
-    container: SpiritApplicationContainer = None
+    CONTAINER: SpiritApplicationContainer = None
 
-    __close_signature = None
+    __CLOSE_SIGNATURE = None
 
     @classmethod
     def start_server(cls, host, port):
-        cls.__socket_server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        cls.__listener_count = 100000
-        cls.__buffer_size = 4096
-        cls.__executor = ThreadExecutor(executor_count=cls.__listener_count + 1)
-        cls.__socket_server.bind((host, port))
-        cls.__socket_server.listen(cls.__listener_count)
-        cls.__executor.execute(cls.__listener_connection)
-        cls.__close_signature = ""
+        cls.__SOCKET_SERVER = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        cls.__LISTENER_COUNT = 100000
+        cls.__BUFFER_SIZE = 4096
+        cls.__EXECUTOR = ThreadExecutor(executor_count=cls.__LISTENER_COUNT + 1)
+        cls.__SOCKET_SERVER.bind((host, port))
+        cls.__SOCKET_SERVER.listen(cls.__LISTENER_COUNT)
+        cls.__EXECUTOR.execute(cls.__listener_connection)
+        cls.__CLOSE_SIGNATURE = ""
         info(f"WebSocket Server listening on ws://{host}:{port}")
 
     class Session:
-        __socket: socket.socket = None
-
-        __address: tuple[str, int] = None
-
-        __buffer_size: int = None
-
-        __is_connected: bool = None
-
-        __headers: dict = None
-
-        __params: dict = None
-
-        __start_connected_timer: float = None
-
-        __close_connected_timer: float = None
 
         def __init__(self,
                      socket_client: socket.socket,
                      address: tuple[str, int],
-                     headers: dict,
-                     params: dict,
-                     is_connected: bool = True,
-                     buffer_size: int = 4096):
-            self.__socket = socket_client
-            self.__address = address
-            self.__headers = headers
-            self.__params = params
-            self.__is_connected = is_connected
-            self.__buffer_size = buffer_size
-            self.__start_connected_timer = time.time()
+                     headers: dict[str, str],
+                     params: dict[str, str | int]):
+            self.__socket: socket.socket = socket_client
+            self.__address: tuple[str, int] = address
+            self.__headers: dict[str, str] = headers
+            self.__params: dict[str, str | int] = params
+            self.__is_connected: bool = True
+            self.__start_connected_timer: float = time.time()
+            self.__close_connected_timer: float | None = None
 
         def get_socket_client(self) -> socket.socket:
             return self.__socket
@@ -154,7 +137,7 @@ class WebSocket(ABC):
                 info(f"Disconnecting Session: {self}")
                 self.__send_close_frame(code=close_code, reason=reason)
                 self.__socket.close()
-                __endpoint = WebSocket.container.remove_resource(signature=str(self.__address))
+                __endpoint = WebSocket.CONTAINER.remove_resource(signature=str(self.__address))
                 __onclose: callable = __endpoint.ws_funcs["OnClose"]
                 if __onclose is not None:
                     __onclose(__endpoint, session=self)
@@ -230,13 +213,13 @@ class WebSocket(ABC):
     def __listener_connection(cls) -> None:
         while True:
             try:
-                socket_client, addr = cls.__socket_server.accept()
+                socket_client, addr = cls.__SOCKET_SERVER.accept()
                 # 缓冲区分块接收，直到遇到 \r\n\r\n
                 header_data: bytes | None = None
 
                 buffer = bytearray()
                 while True:
-                    chunk = socket_client.recv(cls.__buffer_size)  # 每次接收 4KB
+                    chunk = socket_client.recv(cls.__BUFFER_SIZE)  # 每次接收 4KB
                     if not chunk:  # 连接关闭
                         break
                     buffer.extend(chunk)
@@ -252,7 +235,7 @@ class WebSocket(ABC):
                     params: dict[str, str | int] = {}
                     header_str = header_data.decode("utf-8")
                     lines = header_str.split("\r\n")
-                    for end_point_cls in cls.websocket_end_points:
+                    for end_point_cls in cls.WEBSOCKET_END_POINTS:
                         signature = getattr(end_point_cls, "__decorator_signature__")
                         paths = lines[0].split(signature)
                         if len(paths) == 2 and paths[0][-1] == " " and paths[1][0] in (" ", "?"):
@@ -287,13 +270,13 @@ class WebSocket(ABC):
                     continue
                 if cls.__handshaking(socket_client=socket_client, ws_headers=ws_headers):
                     __endpoint = ws_endpoint_cls()
-                    cls.container.set_resource(signature=str(addr), resource=__endpoint)
+                    cls.CONTAINER.set_resource(signature=str(addr), resource=__endpoint)
                     session = cls.Session(socket_client=socket_client,
                                           address=addr,
                                           headers=ws_headers,
                                           params=params)
                     info(f"Session: {session} connection successful")
-                    cls.__executor.execute(task=cls.__listener_message, end_point=__endpoint, session=session)
+                    cls.__EXECUTOR.execute(task=cls.__listener_message, end_point=__endpoint, session=session)
                     __onopen: callable = __endpoint.ws_funcs["OnOpen"]
                     if __onopen is not None:
                         __onopen(__endpoint, session=session)
@@ -305,7 +288,7 @@ class WebSocket(ABC):
         # 接收消息
         socket_client: socket.socket = session.get_socket_client()
         session_id = id(socket_client)
-        data = end_point.partial_data.get(socket_client, b'') + socket_client.recv(cls.__buffer_size)
+        data = end_point.partial_data.get(socket_client, b'') + socket_client.recv(cls.__BUFFER_SIZE)
 
         try:
             while len(data) >= 2:
@@ -405,7 +388,7 @@ class WebSocket(ABC):
                     continue
                 elif message == "ping":
                     session.send_message("pong")
-                elif message == cls.__close_signature:
+                elif message == cls.__CLOSE_SIGNATURE:
                     session.close()
                 else:
                     __onmessage: callable = end_point.ws_funcs["OnMessage"]
@@ -423,9 +406,9 @@ class WebSocket(ABC):
 
 class WebSocketServer:
     def __init__(self, host: str, port: int) -> None:
-        if WebSocket.container is None:
-            WebSocket.container = SpiritApplicationContainer()
-        WebSocket.container.set_resource(signature="WebSocketServer", resource=self)
+        if WebSocket.CONTAINER is None:
+            WebSocket.CONTAINER = SpiritApplicationContainer()
+        WebSocket.CONTAINER.set_resource(signature="WebSocketServer", resource=self)
         self.__host: str = host
         self.__port: int = port
 
@@ -458,9 +441,9 @@ class EndPoint:
                 if decorator in ["OnOpen", "OnMessage", "OnError", "OnClose"]:
                     ws_funcs[decorator] = method
         end_point_cls.ws_funcs = ws_funcs
-        if WebSocket.websocket_end_points is None:
-            WebSocket.websocket_end_points = set()
-        WebSocket.websocket_end_points.add(end_point_cls)
+        if WebSocket.WEBSOCKET_END_POINTS is None:
+            WebSocket.WEBSOCKET_END_POINTS = set()
+        WebSocket.WEBSOCKET_END_POINTS.add(end_point_cls)
         return end_point_cls
 
 
